#!/usr/bin/python
"""
gtview - Simple Gtk image viewer

Copyright (C) 2001 James ''Wez''Weatherall

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

ToDo:
1.  Make it handle xpms, which it currently doesn't!
2.  Deal better with multiple views, for pylau.

"""

try: import pylau
except ImportError: pass

import gtk
import sys
try: import GdkImlib
except ImportError: pass

view_mgr = None
view_id = 0

class GtView(gtk.GtkWindow):
    def __init__(self, file, width=0, height=0):
        gtk.GtkWindow.__init__(self)
        self.quit_on_destroy = 0

        image = GdkImlib.Image(file)
        if not width: width = image.rgb_width
        if not height: height = image.rgb_height
        if not image.render(width, height): raise "Can't Render Image"
        pixmap = image.make_pixmap()
        pixmap.show()
        view = gtk.GtkScrolledWindow()
        view.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
        view.add_with_viewport(pixmap)
        self.__view = view
        self.add(view)
        self.set_default_size(width, height)
        self.show_all()
        
        self.connect("destroy", self.OnDestroy)
        if self.__view: self.connect("key-press-event", self.OnKeyPress)
        view_mgr.Add(self)
    def OnDestroy(self, widget):
        view_mgr.Remove(self)
    def OnKeyPress(self, widget, event):
        if event.keyval == 65361:
            change = -1
            adjust = self.__view.get_hadjustment()
        elif event.keyval == 65363:
            change = 1
            adjust = self.__view.get_hadjustment()
        elif event.keyval == 65362:
            change = -1
            adjust = self.__view.get_vadjustment()
        elif event.keyval == 65364:
            change = 1
            adjust = self.__view.get_vadjustment()
        elif event.string == "q":
            self.destroy()
            return
        value = adjust.value+(change*adjust.step_increment)
        adjust.set_value(max(0, min(value, adjust.upper-adjust.page_size)))

class GtViewMgr:
    def __init__(self):
        self.views = []
    def Add(self, view):
        self.views.append(view)
    def Remove(self, view):
        self.views.remove(view)
        if not self.views:
            gtk.mainquit()
    def Count(self):
        return len(self.views)

def Main(argv):
    global view_mgr
    if not view_mgr: view_mgr = GtViewMgr()
    mode = 0
    width = 0
    height = 0
    for file in argv[1:]:
        if file == "-width":
            mode = 1
        elif file == "-height":
            mode = 2
        elif mode == 0:
            try:
                view = GtView(file, width, height)
            except:
                pass
        elif mode == 1:
            width = int(file)
            mode=0
        elif mode == 2:
            height=int(file)
            mode = 0
    if not view_mgr.Count(): view_mgr = None
    if view_mgr: gtk.mainloop()

if __name__ == "__main__": Main(sys.argv)


